oumi.models.experimental.cambrian.model
=======================================
.. automodule:: oumi.models.experimental.cambrian.model
   :members:
   :undoc-members:
   :show-inheritance:

Subpackages
-----------

.. toctree::
   :maxdepth: 2

   oumi.models.experimental.cambrian.model.language_model
   oumi.models.experimental.cambrian.model.multimodal_encoder
   oumi.models.experimental.cambrian.model.multimodal_projector
